==> cabal-install-3.10.3.0-6-loong64.pkg.tar.zst: usr/share/haskell/register/cabal-install.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install
version:              3.10.3.0
visibility:           public
id:                   cabal-install-3.10.3.0-3finME7UrGk5AnEUH50y8A
key:                  cabal-install-3.10.3.0-3finME7UrGk5AnEUH50y8A
license:              BSD-3-Clause
copyright:            2003-2023, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The \'\''cabal\'\'' command-line program simplifies the process of managing
    Haskell software by automating the fetching, configuration, compilation
    and installation of Haskell libraries and programs.

category:             Distribution
abi:                  26de533fbc4056dd48cb46b11ef04557
exposed:              True
exposed-modules:
    Distribution.Client.BuildReports.Anonymous
    Distribution.Client.BuildReports.Lens
    Distribution.Client.BuildReports.Storage
    Distribution.Client.BuildReports.Types
    Distribution.Client.BuildReports.Upload Distribution.Client.Check
    Distribution.Client.CmdBench Distribution.Client.CmdBuild
    Distribution.Client.CmdClean Distribution.Client.CmdConfigure
    Distribution.Client.CmdErrorMessages Distribution.Client.CmdExec
    Distribution.Client.CmdFreeze Distribution.Client.CmdHaddock
    Distribution.Client.CmdHaddockProject
    Distribution.Client.CmdInstall
    Distribution.Client.CmdInstall.ClientInstallFlags
    Distribution.Client.CmdInstall.ClientInstallTargetSelector
    Distribution.Client.CmdLegacy Distribution.Client.CmdListBin
    Distribution.Client.CmdOutdated Distribution.Client.CmdRepl
    Distribution.Client.CmdRun Distribution.Client.CmdSdist
    Distribution.Client.CmdTest Distribution.Client.CmdUpdate
    Distribution.Client.Compat.Directory
    Distribution.Client.Compat.ExecutablePath
    Distribution.Client.Compat.Orphans
    Distribution.Client.Compat.Prelude
    Distribution.Client.Compat.Semaphore Distribution.Client.Compat.Tar
    Distribution.Client.Config Distribution.Client.Configure
    Distribution.Client.Dependency Distribution.Client.Dependency.Types
    Distribution.Client.DistDirLayout Distribution.Client.Fetch
    Distribution.Client.FetchUtils Distribution.Client.FileMonitor
    Distribution.Client.Freeze Distribution.Client.GZipUtils
    Distribution.Client.GenBounds Distribution.Client.Get
    Distribution.Client.Glob Distribution.Client.GlobalFlags
    Distribution.Client.Haddock Distribution.Client.HashValue
    Distribution.Client.HttpUtils Distribution.Client.IndexUtils
    Distribution.Client.IndexUtils.ActiveRepos
    Distribution.Client.IndexUtils.IndexState
    Distribution.Client.IndexUtils.Timestamp Distribution.Client.Init
    Distribution.Client.Init.Defaults
    Distribution.Client.Init.FileCreators
    Distribution.Client.Init.FlagExtractors
    Distribution.Client.Init.Format
    Distribution.Client.Init.Interactive.Command
    Distribution.Client.Init.Licenses
    Distribution.Client.Init.NonInteractive.Command
    Distribution.Client.Init.NonInteractive.Heuristics
    Distribution.Client.Init.Prompt Distribution.Client.Init.Simple
    Distribution.Client.Init.Types Distribution.Client.Init.Utils
    Distribution.Client.Install Distribution.Client.InstallPlan
    Distribution.Client.InstallSymlink Distribution.Client.JobControl
    Distribution.Client.List Distribution.Client.Main
    Distribution.Client.Manpage Distribution.Client.ManpageFlags
    Distribution.Client.Nix Distribution.Client.NixStyleOptions
    Distribution.Client.PackageHash Distribution.Client.ParseUtils
    Distribution.Client.ProjectBuilding
    Distribution.Client.ProjectBuilding.Types
    Distribution.Client.ProjectConfig
    Distribution.Client.ProjectConfig.Legacy
    Distribution.Client.ProjectConfig.Types
    Distribution.Client.ProjectFlags
    Distribution.Client.ProjectOrchestration
    Distribution.Client.ProjectPlanOutput
    Distribution.Client.ProjectPlanning
    Distribution.Client.ProjectPlanning.Types
    Distribution.Client.RebuildMonad Distribution.Client.Reconfigure
    Distribution.Client.Run Distribution.Client.Sandbox
    Distribution.Client.Sandbox.PackageEnvironment
    Distribution.Client.SavedFlags Distribution.Client.ScriptUtils
    Distribution.Client.Security.DNS Distribution.Client.Security.HTTP
    Distribution.Client.Setup Distribution.Client.SetupWrapper
    Distribution.Client.Signal Distribution.Client.SolverInstallPlan
    Distribution.Client.SourceFiles Distribution.Client.SrcDist
    Distribution.Client.Store Distribution.Client.Tar
    Distribution.Client.TargetProblem
    Distribution.Client.TargetSelector Distribution.Client.Targets
    Distribution.Client.Types Distribution.Client.Types.AllowNewer
    Distribution.Client.Types.BuildResults
    Distribution.Client.Types.ConfiguredId
    Distribution.Client.Types.ConfiguredPackage
    Distribution.Client.Types.Credentials
    Distribution.Client.Types.InstallMethod
    Distribution.Client.Types.OverwritePolicy
    Distribution.Client.Types.PackageLocation
    Distribution.Client.Types.PackageSpecifier
    Distribution.Client.Types.ReadyPackage
    Distribution.Client.Types.Repo Distribution.Client.Types.RepoName
    Distribution.Client.Types.SourcePackageDb
    Distribution.Client.Types.SourceRepo
    Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy
    Distribution.Client.Upload Distribution.Client.Utils
    Distribution.Client.Utils.Json Distribution.Client.Utils.Parsec
    Distribution.Client.VCS Distribution.Client.Version
    Distribution.Client.Win32SelfUpgrade
    Distribution.Deprecated.ParseUtils Distribution.Deprecated.ReadP
    Distribution.Deprecated.ViewAsFieldDescr

hidden-modules:       Paths_cabal_install
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-install
hs-libraries:         HScabal-install-3.10.3.0-3finME7UrGk5AnEUH50y8A
depends:
    Cabal-3.10.3.0 Cabal-syntax-3.10.3.0
    HTTP-4000.4.1-9QKOH3moG66E3gEMmY9ujp array-0.5.6.0
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-solver-3.10.3.0-6FF9NRIxrQNCCodmsU9m0E
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-4oSM5otI4Ra8wFWOp2kkt3
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    edit-distance-0.2.2.1-3CAlnCOf2qnK3OKBOHZEYU exceptions-0.10.7
    filepath-1.4.300.1 hackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    lukko-0.1.2-E4j9X9UkkjjAmzjgwplom6 mtl-2.3.1
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    resolv-0.2.0.3-1sMWibCMmEVBxMfAKaxUhq
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI stm-2.5.1.0
    tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a text-2.0.2 time-1.12.2
    unix-2.8.4.0 zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:   /usr/share/doc/cabal-install/html/cabal-install.haddock
haddock-html:         /usr/share/doc/cabal-install/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-install-3.10.3.0-8-loong64.pkg.tar.zst: usr/share/haskell/register/cabal-install.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install
version:              3.10.3.0
visibility:           public
id:                   cabal-install-3.10.3.0-A2JpJ65OyEoHGzYa6jl1mc
key:                  cabal-install-3.10.3.0-A2JpJ65OyEoHGzYa6jl1mc
license:              BSD-3-Clause
copyright:            2003-2023, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The \'\''cabal\'\'' command-line program simplifies the process of managing
    Haskell software by automating the fetching, configuration, compilation
    and installation of Haskell libraries and programs.

category:             Distribution
abi:                  b6d4ed8c23f2c62dd9a117a723953d9e
exposed:              True
exposed-modules:
    Distribution.Client.BuildReports.Anonymous
    Distribution.Client.BuildReports.Lens
    Distribution.Client.BuildReports.Storage
    Distribution.Client.BuildReports.Types
    Distribution.Client.BuildReports.Upload Distribution.Client.Check
    Distribution.Client.CmdBench Distribution.Client.CmdBuild
    Distribution.Client.CmdClean Distribution.Client.CmdConfigure
    Distribution.Client.CmdErrorMessages Distribution.Client.CmdExec
    Distribution.Client.CmdFreeze Distribution.Client.CmdHaddock
    Distribution.Client.CmdHaddockProject
    Distribution.Client.CmdInstall
    Distribution.Client.CmdInstall.ClientInstallFlags
    Distribution.Client.CmdInstall.ClientInstallTargetSelector
    Distribution.Client.CmdLegacy Distribution.Client.CmdListBin
    Distribution.Client.CmdOutdated Distribution.Client.CmdRepl
    Distribution.Client.CmdRun Distribution.Client.CmdSdist
    Distribution.Client.CmdTest Distribution.Client.CmdUpdate
    Distribution.Client.Compat.Directory
    Distribution.Client.Compat.ExecutablePath
    Distribution.Client.Compat.Orphans
    Distribution.Client.Compat.Prelude
    Distribution.Client.Compat.Semaphore Distribution.Client.Compat.Tar
    Distribution.Client.Config Distribution.Client.Configure
    Distribution.Client.Dependency Distribution.Client.Dependency.Types
    Distribution.Client.DistDirLayout Distribution.Client.Fetch
    Distribution.Client.FetchUtils Distribution.Client.FileMonitor
    Distribution.Client.Freeze Distribution.Client.GZipUtils
    Distribution.Client.GenBounds Distribution.Client.Get
    Distribution.Client.Glob Distribution.Client.GlobalFlags
    Distribution.Client.Haddock Distribution.Client.HashValue
    Distribution.Client.HttpUtils Distribution.Client.IndexUtils
    Distribution.Client.IndexUtils.ActiveRepos
    Distribution.Client.IndexUtils.IndexState
    Distribution.Client.IndexUtils.Timestamp Distribution.Client.Init
    Distribution.Client.Init.Defaults
    Distribution.Client.Init.FileCreators
    Distribution.Client.Init.FlagExtractors
    Distribution.Client.Init.Format
    Distribution.Client.Init.Interactive.Command
    Distribution.Client.Init.Licenses
    Distribution.Client.Init.NonInteractive.Command
    Distribution.Client.Init.NonInteractive.Heuristics
    Distribution.Client.Init.Prompt Distribution.Client.Init.Simple
    Distribution.Client.Init.Types Distribution.Client.Init.Utils
    Distribution.Client.Install Distribution.Client.InstallPlan
    Distribution.Client.InstallSymlink Distribution.Client.JobControl
    Distribution.Client.List Distribution.Client.Main
    Distribution.Client.Manpage Distribution.Client.ManpageFlags
    Distribution.Client.Nix Distribution.Client.NixStyleOptions
    Distribution.Client.PackageHash Distribution.Client.ParseUtils
    Distribution.Client.ProjectBuilding
    Distribution.Client.ProjectBuilding.Types
    Distribution.Client.ProjectConfig
    Distribution.Client.ProjectConfig.Legacy
    Distribution.Client.ProjectConfig.Types
    Distribution.Client.ProjectFlags
    Distribution.Client.ProjectOrchestration
    Distribution.Client.ProjectPlanOutput
    Distribution.Client.ProjectPlanning
    Distribution.Client.ProjectPlanning.Types
    Distribution.Client.RebuildMonad Distribution.Client.Reconfigure
    Distribution.Client.Run Distribution.Client.Sandbox
    Distribution.Client.Sandbox.PackageEnvironment
    Distribution.Client.SavedFlags Distribution.Client.ScriptUtils
    Distribution.Client.Security.DNS Distribution.Client.Security.HTTP
    Distribution.Client.Setup Distribution.Client.SetupWrapper
    Distribution.Client.Signal Distribution.Client.SolverInstallPlan
    Distribution.Client.SourceFiles Distribution.Client.SrcDist
    Distribution.Client.Store Distribution.Client.Tar
    Distribution.Client.TargetProblem
    Distribution.Client.TargetSelector Distribution.Client.Targets
    Distribution.Client.Types Distribution.Client.Types.AllowNewer
    Distribution.Client.Types.BuildResults
    Distribution.Client.Types.ConfiguredId
    Distribution.Client.Types.ConfiguredPackage
    Distribution.Client.Types.Credentials
    Distribution.Client.Types.InstallMethod
    Distribution.Client.Types.OverwritePolicy
    Distribution.Client.Types.PackageLocation
    Distribution.Client.Types.PackageSpecifier
    Distribution.Client.Types.ReadyPackage
    Distribution.Client.Types.Repo Distribution.Client.Types.RepoName
    Distribution.Client.Types.SourcePackageDb
    Distribution.Client.Types.SourceRepo
    Distribution.Client.Types.WriteGhcEnvironmentFilesPolicy
    Distribution.Client.Upload Distribution.Client.Utils
    Distribution.Client.Utils.Json Distribution.Client.Utils.Parsec
    Distribution.Client.VCS Distribution.Client.Version
    Distribution.Client.Win32SelfUpgrade
    Distribution.Deprecated.ParseUtils Distribution.Deprecated.ReadP
    Distribution.Deprecated.ViewAsFieldDescr

hidden-modules:       Paths_cabal_install
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-3.10.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-install
hs-libraries:         HScabal-install-3.10.3.0-A2JpJ65OyEoHGzYa6jl1mc
depends:
    Cabal-3.10.3.0 Cabal-syntax-3.10.3.0
    HTTP-4000.4.1-LiE2KGoUj7cHY0TLoqm68A array-0.5.6.0
    async-2.2.5-BOONqED6PxbDsY8XxcvMc4 base-4.18.2.1
    base16-bytestring-1.0.2.0-6gPusxqn90AJxFEjBUebK6 binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-solver-3.10.3.0-7hXZ9EYy0VHL3mth98wD9M
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-8XHw5QTKQKOLRqWL48SiFE
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    edit-distance-0.2.2.1-LUzNiWZMoGc752FvDibC8b exceptions-0.10.7
    filepath-1.4.300.1 hackage-security-0.6.3.2-9OIwM6iQ1rKFA17gmZ41Ld
    hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    lukko-0.1.2-KejXjpugzbk4KuA4hzbs3G mtl-2.3.1
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-6l1YOhgkyj83HD6td8a68Q
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    resolv-0.2.0.3-K7BHcXo5expIuNbyoLGnlv
    safe-exceptions-0.1.7.4-CBGnyYEnBKB3bMqSoAV5tn stm-2.5.1.0
    tar-0.5.1.1-JlMgyVtEPtgCJ9zPWV7bRw text-2.0.2 time-1.12.2
    unix-2.8.4.0 zlib-0.7.0.0-KycIpdUZG34Fi5Aj6BOrFq

haddock-interfaces:   /usr/share/doc/cabal-install/html/cabal-install.haddock
haddock-html:         /usr/share/doc/cabal-install/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
